CorePlayer

Enum CorePlayer 

#[repr(u8)]
pub enum CorePlayer { FirstAttackPlayer = 0, SecondAttackPlayer = 1, None = 2, All = 3, Rule = 5, }
The position where a player is in ygocore.

This is a new type invented by this crate. Its values are exactly the same as the player in ygocore (often written as tp in lua). They are unrelated to the network slot of the first-attack player, so CorePlayer is not equal to Netplayer. How to relate Netplayer and CorePlayer is the downstream’s own responsibility.

See also: Netplayer.

Variants



FirstAttackPlayer = 0



SecondAttackPlayer = 1



None = 2



All = 3



Rule = 5

This value is only used as reason_player when reason is rule.

Implementations