pub struct PlayerChange { /* private fields */ }Implementations
Sourceimpl PlayerChange
impl PlayerChange
Sourceimpl PlayerChange
impl PlayerChange
Sourcepub const fn into_bytes(self) -> [u8; 1]
pub const fn into_bytes(self) -> [u8; 1]
Sourcepub const fn from_bytes(bytes: [u8; 1]) -> Self
pub const fn from_bytes(bytes: [u8; 1]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourceimpl PlayerChange
impl PlayerChange
Sourcepub fn state(&self) -> <PlayerChangeState as Specifier>::InOut
pub fn state(&self) -> <PlayerChangeState as Specifier>::InOut
Returns the value of state.
Sourcepub fn state_or_err(
&self,
) -> Result<<PlayerChangeState as Specifier>::InOut, InvalidBitPattern<<PlayerChangeState as Specifier>::Bytes>>
pub fn state_or_err( &self, ) -> Result<<PlayerChangeState as Specifier>::InOut, InvalidBitPattern<<PlayerChangeState as Specifier>::Bytes>>
Returns the value of state.
Errors
If the returned value contains an invalid bit pattern for state.
Sourcepub fn with_state(
self,
new_val: <PlayerChangeState as Specifier>::InOut,
) -> Self
pub fn with_state( self, new_val: <PlayerChangeState as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of state set to the given value.
Panics
If the given value is out of bounds for state.
Sourcepub fn with_state_checked(
self,
new_val: <PlayerChangeState as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_state_checked( self, new_val: <PlayerChangeState as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of state set to the given value.
Errors
If the given value is out of bounds for state.
Sourcepub fn set_state(&mut self, new_val: <PlayerChangeState as Specifier>::InOut)
pub fn set_state(&mut self, new_val: <PlayerChangeState as Specifier>::InOut)
Sourcepub fn set_state_checked(
&mut self,
new_val: <PlayerChangeState as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_state_checked( &mut self, new_val: <PlayerChangeState as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sourcepub fn player_or_err(
&self,
) -> Result<<Netplayer as Specifier>::InOut, InvalidBitPattern<<Netplayer as Specifier>::Bytes>>
pub fn player_or_err( &self, ) -> Result<<Netplayer as Specifier>::InOut, InvalidBitPattern<<Netplayer as Specifier>::Bytes>>
Returns the value of player.
Errors
If the returned value contains an invalid bit pattern for player.
Sourcepub fn with_player(self, new_val: <Netplayer as Specifier>::InOut) -> Self
pub fn with_player(self, new_val: <Netplayer as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of player set to the given value.
Panics
If the given value is out of bounds for player.
Sourcepub fn with_player_checked(
self,
new_val: <Netplayer as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_player_checked( self, new_val: <Netplayer as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of player set to the given value.
Errors
If the given value is out of bounds for player.
Sourcepub fn set_player(&mut self, new_val: <Netplayer as Specifier>::InOut)
pub fn set_player(&mut self, new_val: <Netplayer as Specifier>::InOut)
Sets the value of player to the given value.
Panics
If the given value is out of bounds for player.
Sourcepub fn set_player_checked(
&mut self,
new_val: <Netplayer as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_player_checked( &mut self, new_val: <Netplayer as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of player to the given value.
Errors
If the given value is out of bounds for player.