pub struct CardPosition<const CODE: bool, const SUB_SEQUENCE: bool, const DESCRIPTION: bool> {
pub code: CardCode,
pub controller: CorePlayer,
pub location: Location,
pub sequence: i8,
pub sub_sequence: i8,
pub description: i32,
}Fields
code: CardCodecontroller: CorePlayerlocation: Locationsequence: i8sub_sequence: i8description: i32Trait Implementations
Sourceimpl<const CODE: bool, const SUB_SEQUENCE: bool, const DESCRIPTION: bool> BinRead for CardPosition<CODE, SUB_SEQUENCE, DESCRIPTION>
impl<const CODE: bool, const SUB_SEQUENCE: bool, const DESCRIPTION: bool> BinRead for CardPosition<CODE, SUB_SEQUENCE, DESCRIPTION>
Sourcefn read_options<R: Read + Seek>(
__binrw_generated_var_reader: &mut R,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: Self::Args<'_>,
) -> BinResult<Self>
fn read_options<R: Read + Seek>( __binrw_generated_var_reader: &mut R, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: Self::Args<'_>, ) -> BinResult<Self>
Sourcefn read_be<R>(reader: &mut R) -> Result<Self, Error>
fn read_be<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
big-endian byte order. Read moreSourcefn read_le<R>(reader: &mut R) -> Result<Self, Error>
fn read_le<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
little-endian byte order. Read moreSourcefn read_ne<R>(reader: &mut R) -> Result<Self, Error>
fn read_ne<R>(reader: &mut R) -> Result<Self, Error>
Read
T from the reader assuming native-endian byte order. Read moreSourcefn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
fn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
Read
Self from the reader, assuming big-endian byte order, using the
given arguments. Read moreSourceimpl<const CODE: bool, const SUB_SEQUENCE: bool, const DESCRIPTION: bool> BinWrite for CardPosition<CODE, SUB_SEQUENCE, DESCRIPTION>
impl<const CODE: bool, const SUB_SEQUENCE: bool, const DESCRIPTION: bool> BinWrite for CardPosition<CODE, SUB_SEQUENCE, DESCRIPTION>
Sourcefn write_options<W: Write + Seek>(
&self,
__binrw_generated_var_writer: &mut W,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: Self::Args<'_>,
) -> BinResult<()>
fn write_options<W: Write + Seek>( &self, __binrw_generated_var_writer: &mut W, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: Self::Args<'_>, ) -> BinResult<()>
Sourcefn write_be<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_be<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming big-endian byte order. Read moreSourcefn write_le<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_le<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming little-endian byte order. Read moreSourceimpl<const CODE: bool, const SUB_SEQUENCE: bool, const DESCRIPTION: bool> Clone for CardPosition<CODE, SUB_SEQUENCE, DESCRIPTION>
impl<const CODE: bool, const SUB_SEQUENCE: bool, const DESCRIPTION: bool> Clone for CardPosition<CODE, SUB_SEQUENCE, DESCRIPTION>
Sourcefn clone(&self) -> CardPosition<CODE, SUB_SEQUENCE, DESCRIPTION>
fn clone(&self) -> CardPosition<CODE, SUB_SEQUENCE, DESCRIPTION>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<const CODE: bool, const SUB_SEQUENCE: bool, const DESCRIPTION: bool> Debug for CardPosition<CODE, SUB_SEQUENCE, DESCRIPTION>
impl<const CODE: bool, const SUB_SEQUENCE: bool, const DESCRIPTION: bool> Debug for CardPosition<CODE, SUB_SEQUENCE, DESCRIPTION>
Sourceimpl<const CODE: bool, const SUB_SEQUENCE: bool, const DESCRIPTION: bool> GameMessage for CardPosition<CODE, SUB_SEQUENCE, DESCRIPTION>
impl<const CODE: bool, const SUB_SEQUENCE: bool, const DESCRIPTION: bool> GameMessage for CardPosition<CODE, SUB_SEQUENCE, DESCRIPTION>
fn mask(&mut self)
fn should_mask(&self, player: CorePlayer) -> bool
fn waiting_for(&self) -> Option<CorePlayer>