pub struct ReplayBody {Show 14 fields
pub host_name: FixedLengthString<20>,
pub tag_host_name: Option<FixedLengthString<20>>,
pub tag_client_name: Option<FixedLengthString<20>>,
pub client_name: FixedLengthString<20>,
pub start_lp: u32,
pub start_hand: u32,
pub draw_count: u32,
pub duel_options: DuelOptions,
pub duel_rule: u16,
pub host_deck: ReplayDeck,
pub tag_host_deck: Option<ReplayDeck>,
pub client_deck: ReplayDeck,
pub tag_client_deck: Option<ReplayDeck>,
pub datas: Vec<ReplayData>,
}Fields
host_name: FixedLengthString<20>tag_host_name: Option<FixedLengthString<20>>tag_client_name: Option<FixedLengthString<20>>client_name: FixedLengthString<20>start_lp: u32start_hand: u32draw_count: u32duel_options: DuelOptionsduel_rule: u16host_deck: ReplayDecktag_host_deck: Option<ReplayDeck>client_deck: ReplayDecktag_client_deck: Option<ReplayDeck>datas: Vec<ReplayData>Trait Implementations
Sourceimpl BinRead for ReplayBody
impl BinRead for ReplayBody
Sourcetype Args<'__binrw_generated_args_lifetime> = (&'__binrw_generated_args_lifetime ReplayHeader,)
type Args<'__binrw_generated_args_lifetime> = (&'__binrw_generated_args_lifetime ReplayHeader,)
Sourcefn read_options<R: Read + Seek>(
__binrw_generated_var_reader: &mut R,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: Self::Args<'_>,
) -> BinResult<Self>
fn read_options<R: Read + Seek>( __binrw_generated_var_reader: &mut R, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: Self::Args<'_>, ) -> BinResult<Self>
Sourcefn read_be<R>(reader: &mut R) -> Result<Self, Error>
fn read_be<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
big-endian byte order. Read moreSourcefn read_le<R>(reader: &mut R) -> Result<Self, Error>
fn read_le<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
little-endian byte order. Read moreSourcefn read_ne<R>(reader: &mut R) -> Result<Self, Error>
fn read_ne<R>(reader: &mut R) -> Result<Self, Error>
Read
T from the reader assuming native-endian byte order. Read moreSourcefn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
fn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
Read
Self from the reader, assuming big-endian byte order, using the
given arguments. Read moreSourceimpl BinWrite for ReplayBody
impl BinWrite for ReplayBody
Sourcetype Args<'__binrw_generated_args_lifetime> = (&'__binrw_generated_args_lifetime ReplayHeader,)
type Args<'__binrw_generated_args_lifetime> = (&'__binrw_generated_args_lifetime ReplayHeader,)
Sourcefn write_options<W: Write + Seek>(
&self,
__binrw_generated_var_writer: &mut W,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: Self::Args<'_>,
) -> BinResult<()>
fn write_options<W: Write + Seek>( &self, __binrw_generated_var_writer: &mut W, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: Self::Args<'_>, ) -> BinResult<()>
Sourcefn write_be<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_be<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming big-endian byte order. Read moreSourcefn write_le<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_le<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming little-endian byte order. Read moreSourceimpl Clone for ReplayBody
impl Clone for ReplayBody
Sourcefn clone(&self) -> ReplayBody
fn clone(&self) -> ReplayBody
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl !Freeze for ReplayBody
impl RefUnwindSafe for ReplayBody
impl Send for ReplayBody
impl Sync for ReplayBody
impl Unpin for ReplayBody
impl UnsafeUnpin for ReplayBody
impl UnwindSafe for ReplayBody