pub struct ReplayDeck {
pub main: Vec<u32>,
pub extra: Vec<u32>,
}Expand description
Deck saved in replay.
Replay Deck binary layout is different from Deck.
Fields
main: Vec<u32>extra: Vec<u32>Trait Implementations
Sourceimpl BinRead for ReplayDeck
impl BinRead for ReplayDeck
Sourcefn read_options<R: Read + Seek>(
__binrw_generated_var_reader: &mut R,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: Self::Args<'_>,
) -> BinResult<Self>
fn read_options<R: Read + Seek>( __binrw_generated_var_reader: &mut R, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: Self::Args<'_>, ) -> BinResult<Self>
Sourcefn read_be<R>(reader: &mut R) -> Result<Self, Error>
fn read_be<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
big-endian byte order. Read moreSourcefn read_le<R>(reader: &mut R) -> Result<Self, Error>
fn read_le<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
little-endian byte order. Read moreSourcefn read_ne<R>(reader: &mut R) -> Result<Self, Error>
fn read_ne<R>(reader: &mut R) -> Result<Self, Error>
Read
T from the reader assuming native-endian byte order. Read moreSourcefn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
fn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
Read
Self from the reader, assuming big-endian byte order, using the
given arguments. Read moreSourceimpl BinWrite for ReplayDeck
impl BinWrite for ReplayDeck
Sourcefn write_options<W: Write + Seek>(
&self,
__binrw_generated_var_writer: &mut W,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: Self::Args<'_>,
) -> BinResult<()>
fn write_options<W: Write + Seek>( &self, __binrw_generated_var_writer: &mut W, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: Self::Args<'_>, ) -> BinResult<()>
Sourcefn write_be<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_be<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming big-endian byte order. Read moreSourcefn write_le<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_le<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming little-endian byte order. Read moreSourceimpl Clone for ReplayDeck
impl Clone for ReplayDeck
Sourcefn clone(&self) -> ReplayDeck
fn clone(&self) -> ReplayDeck
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReplayDeck
impl Debug for ReplayDeck
Sourceimpl Default for ReplayDeck
impl Default for ReplayDeck
Sourcefn default() -> ReplayDeck
fn default() -> ReplayDeck
Returns the “default value” for a type. Read more
impl Eq for ReplayDeck
Sourceimpl From<Deck> for ReplayDeck
impl From<Deck> for ReplayDeck
Sourceimpl From<ReplayDeck> for Deck
impl From<ReplayDeck> for Deck
Sourcefn from(value: ReplayDeck) -> Self
fn from(value: ReplayDeck) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for ReplayDeck
impl PartialEq for ReplayDeck
impl StructuralPartialEq for ReplayDeck