pub struct Card {
pub card: CoreCard,
pub ot: OT,
pub category: Category,
pub name: String,
pub text: String,
pub desc: [String; 16],
}Expand description
A full card, combining the core data with the localized name and text.
Fields
card: CoreCardThe core card data.
ot: OTThe card’s official/ocg/tcg availability.
category: CategoryThe card’s category.
name: StringThe card’s localized name.
text: StringThe card’s localized text.
desc: [String; 16]The card’s desc strings.
Methods from Deref<Target = CoreCard>
Sourcepub fn original_code(&self) -> u32
pub fn original_code(&self) -> u32
The code used to unify cards, falling back to code when there is no alias.
Sourcepub fn duel_code(&self) -> u32
pub fn duel_code(&self) -> u32
The code used in a duel, preferring the rule code over the original code.
Sourcepub fn is_setcodes(&self, value: u32) -> bool
pub fn is_setcodes(&self, value: u32) -> bool
Check whether any set code matches the given value.