pub struct DeckError { /* private fields */ }Expand description
A deck error, packing an error type and the offending card code.
Implementations
Sourceimpl DeckError
impl DeckError
Sourcepub const fn into_bytes(self) -> [u8; 4]
pub const fn into_bytes(self) -> [u8; 4]
Sourcepub const fn from_bytes(bytes: [u8; 4]) -> Self
pub const fn from_bytes(bytes: [u8; 4]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourceimpl DeckError
impl DeckError
Sourcepub fn code(&self) -> <B28 as Specifier>::InOut
pub fn code(&self) -> <B28 as Specifier>::InOut
Returns the value of code.
The offending card code.
Sourcepub fn code_or_err(
&self,
) -> Result<<B28 as Specifier>::InOut, InvalidBitPattern<<B28 as Specifier>::Bytes>>
pub fn code_or_err( &self, ) -> Result<<B28 as Specifier>::InOut, InvalidBitPattern<<B28 as Specifier>::Bytes>>
Returns the value of code.
Errors
If the returned value contains an invalid bit pattern for code.
The offending card code.
Sourcepub fn with_code(self, new_val: <B28 as Specifier>::InOut) -> Self
pub fn with_code(self, new_val: <B28 as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of code set to the given value.
Panics
If the given value is out of bounds for code.
The offending card code.
Sourcepub fn with_code_checked(
self,
new_val: <B28 as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_code_checked( self, new_val: <B28 as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of code set to the given value.
Errors
If the given value is out of bounds for code.
The offending card code.
Sourcepub fn set_code(&mut self, new_val: <B28 as Specifier>::InOut)
pub fn set_code(&mut self, new_val: <B28 as Specifier>::InOut)
Sets the value of code to the given value.
Panics
If the given value is out of bounds for code.
The offending card code.
Sourcepub fn set_code_checked(
&mut self,
new_val: <B28 as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_code_checked( &mut self, new_val: <B28 as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of code to the given value.
Errors
If the given value is out of bounds for code.
The offending card code.
Sourcepub fn error_type(&self) -> <DeckErrorType as Specifier>::InOut
pub fn error_type(&self) -> <DeckErrorType as Specifier>::InOut
Returns the value of error_type.
The error type.
Sourcepub fn error_type_or_err(
&self,
) -> Result<<DeckErrorType as Specifier>::InOut, InvalidBitPattern<<DeckErrorType as Specifier>::Bytes>>
pub fn error_type_or_err( &self, ) -> Result<<DeckErrorType as Specifier>::InOut, InvalidBitPattern<<DeckErrorType as Specifier>::Bytes>>
Returns the value of error_type.
Errors
If the returned value contains an invalid bit pattern for error_type.
The error type.
Sourcepub fn with_error_type(
self,
new_val: <DeckErrorType as Specifier>::InOut,
) -> Self
pub fn with_error_type( self, new_val: <DeckErrorType as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of error_type set to the given value.
Panics
If the given value is out of bounds for error_type.
The error type.
Sourcepub fn with_error_type_checked(
self,
new_val: <DeckErrorType as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_error_type_checked( self, new_val: <DeckErrorType as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of error_type set to the given value.
Errors
If the given value is out of bounds for error_type.
The error type.
Sourcepub fn set_error_type(&mut self, new_val: <DeckErrorType as Specifier>::InOut)
pub fn set_error_type(&mut self, new_val: <DeckErrorType as Specifier>::InOut)
Sets the value of error_type to the given value.
Panics
If the given value is out of bounds for error_type.
The error type.
Sourcepub fn set_error_type_checked(
&mut self,
new_val: <DeckErrorType as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_error_type_checked( &mut self, new_val: <DeckErrorType as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of error_type to the given value.
Errors
If the given value is out of bounds for error_type.
The error type.